WakeupConfig

Struct WakeupConfig 

#[non_exhaustive]
pub struct WakeupConfig { /* private fields */ }
Available on crate feature unstable only.
Configures how the UART wakes the chip from light sleep.

See UartRx::enable_wakeup.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Implementations

Source

impl WakeupConfig

pub fn with_rising_edges(self, rising_edges: u16) -> Self

Assign the given value to the rising_edges field.

pub fn rising_edges(&self) -> u16

The number of rising edges on the RX line that wakes the chip.

The hardware counts edges, and not bytes, so the number of bytes that the chip needs depends on the data of the sender. Each byte gives one rising edge at its stop bit, and one more edge for each change from 0 to 1 in the data. The number of edges is therefore the smallest possible number of bytes. The default is the smallest value that the hardware accepts.

The permitted range on this chip is 3..=1025.